==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/df/dea/road__gui_8cpp.js <==
var road__gui_8cpp =
[
    [ "RoadTypeInfo", "dd/d5a/structRoadTypeInfo.html", "dd/d5a/structRoadTypeInfo" ],
    [ "BuildRoadToolbarWindow", "d7/d35/structBuildRoadToolbarWindow.html", "d7/d35/structBuildRoadToolbarWindow" ],
    [ "BuildRoadDepotWindow", "de/d4a/structBuildRoadDepotWindow.html", "de/d4a/structBuildRoadDepotWindow" ],
    [ "BuildRoadStationWindow", "dc/d4a/structBuildRoadStationWindow.html", "dc/d4a/structBuildRoadStationWindow" ],
    [ "OnButtonClick", "df/dea/road__gui_8cpp.html#a91de73995dd3144aa9c9837202e4afc3", null ],
    [ "RoadFlags", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4", [
      [ "RF_NONE", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4adfaed4cc271948c659c2f1aadea250ef", null ],
      [ "RF_START_HALFROAD_Y", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4afd4af0fadb1166c9e6aa74555bee2b61", null ],
      [ "RF_END_HALFROAD_Y", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a560603c8d9d7406b5c74a7b6fa52c9ba", null ],
      [ "RF_DIR_Y", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a7f2430f6117646323803d916b81e33ba", null ],
      [ "RF_DIR_X", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a8148e364627b79f3e87010a5c4ec5aad", null ],
      [ "RF_START_HALFROAD_X", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a2fe36db344ea801bb5c58e418c901a20", null ],
      [ "RF_END_HALFROAD_X", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a4825b11225162ac4a227c200ba90b1bd", null ]
    ] ],
    [ "CcBuildRoadTunnel", "df/dea/road__gui_8cpp.html#a7dc64be549e50a162400e5cadfd7aee3", null ],
    [ "CcPlaySound_SPLAT_OTHER", "df/dea/road__gui_8cpp.html#a6829511f36a3f2a4e40b422a788e74f4", null ],
    [ "CcRoadDepot", "df/dea/road__gui_8cpp.html#a05dce12a4c9a43bad2e9408fcef1d0c0", null ],
    [ "CcRoadStop", "df/dea/road__gui_8cpp.html#a0212290a51bb3bda94897b8904379027", null ],
    [ "ConnectRoadToStructure", "df/dea/road__gui_8cpp.html#af20a3d9c0f4cd8f947e4da3a1048cb8e", null ],
    [ "InitializeRoadGui", "df/dea/road__gui_8cpp.html#aeb6ddffa8114c12dc4db43f9829ad0b1", null ],
    [ "PlaceRoad_Bridge", "df/dea/road__gui_8cpp.html#a6adeef8b682097227bee2a9b6074843c", null ],
    [ "PlaceRoad_BusStation", "df/dea/road__gui_8cpp.html#a91c5755d81d600b47916247e287a1662", null ],
    [ "PlaceRoad_TruckStation", "df/dea/road__gui_8cpp.html#a425e1752188eeb4b1dccfe2b343ac766", null ],
    [ "PlaceRoadStop", "df/dea/road__gui_8cpp.html#a7d5ca3a311d57669138f9abce00e8a72", null ],
    [ "RoadToolbar_CtrlChanged", "df/dea/road__gui_8cpp.html#abde0f691351de29fec3b895f384ccfd6", null ],
    [ "RoadToolbarGlobalHotkeys", "df/dea/road__gui_8cpp.html#a6825122229da57dda0ece0f0bb21ac5c", null ],
    [ "ShowBuildRoadScenToolbar", "df/dea/road__gui_8cpp.html#a0ea9faf844708a303e398159a19f4943", null ],
    [ "ShowBuildRoadToolbar", "df/dea/road__gui_8cpp.html#a2a953f6481c78539acd18c78e2570dfa", null ],
    [ "ShowRoadDepotPicker", "df/dea/road__gui_8cpp.html#a545cc3523b93794d9142af498d524c43", null ],
    [ "ShowRVStationPicker", "df/dea/road__gui_8cpp.html#a6ef2e122432f64f35d89c8887a85ec25", null ],
    [ "ToggleRoadButton_Remove", "df/dea/road__gui_8cpp.html#aaefa0d76e71df66edba5a5db0fd3bf4d", null ],
    [ "_build_road_depot_desc", "df/dea/road__gui_8cpp.html#a568ae97f9aa0e3367f4ae28bdc9fe757", null ],
    [ "_build_road_desc", "df/dea/road__gui_8cpp.html#adc4fbfb6701cd185ffb76cdddd14d44d", null ],
    [ "_build_road_scen_desc", "df/dea/road__gui_8cpp.html#a481e6b5c388455f4fc421e2dae3c5385", null ],
    [ "_build_tramway_desc", "df/dea/road__gui_8cpp.html#aacb0a2c0687e7bcb45365c4cefdfe710", null ],
    [ "_cur_roadtype", "df/dea/road__gui_8cpp.html#a47c9c607737150786f26d25f419b7a87", null ],
    [ "_nested_build_road_depot_widgets", "df/dea/road__gui_8cpp.html#aa0f23e6a09c47e9102326a7912699edb", null ],
    [ "_nested_build_road_scen_widgets", "df/dea/road__gui_8cpp.html#ab813e468ce61df77234ae8775d7dba22", null ],
    [ "_nested_build_road_widgets", "df/dea/road__gui_8cpp.html#a1ef3d3de78bd5ca692d04e959c6b3da5", null ],
    [ "_nested_build_tramway_widgets", "df/dea/road__gui_8cpp.html#aa59215c8725524bfc9087a3bd702207d", null ],
    [ "_nested_road_station_picker_widgets", "df/dea/road__gui_8cpp.html#a7e19be87654b6ba1d90fd54743de2240", null ],
    [ "_nested_tram_station_picker_widgets", "df/dea/road__gui_8cpp.html#a7a2a397228a9761da8c90697f588e764", null ],
    [ "_one_way_button_clicked", "df/dea/road__gui_8cpp.html#a6cc12fcacadf22b33d111a93607a80f4", null ],
    [ "_place_road_flag", "df/dea/road__gui_8cpp.html#ae039979b32acc50dc75b8c7690db6c21", null ],
    [ "_remove_button_clicked", "df/dea/road__gui_8cpp.html#ae2f45bd332449fcc37e8265e155de154", null ],
    [ "_road_depot_orientation", "df/dea/road__gui_8cpp.html#afea3a0159238725096070659d7887549", null ],
    [ "_road_station_picker_desc", "df/dea/road__gui_8cpp.html#adb1b16b6e773dfe2df947558f83ba62b", null ],
    [ "_road_station_picker_orientation", "df/dea/road__gui_8cpp.html#af77a37be42e7289a8af6a05f3b37760c", null ],
    [ "_road_type_infos", "df/dea/road__gui_8cpp.html#ae32ecb5126828ba6e6e4079cf0ce6b83", null ],
    [ "_tram_station_picker_desc", "df/dea/road__gui_8cpp.html#ae453383855ab148c34d56b35ee7a5547", null ],
    [ "roadtoolbar_hotkeys", "df/dea/road__gui_8cpp.html#adaeec794b2cc8abe9b5084c5226ba767", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/df/dea/road__gui_8cpp.js <==
var road__gui_8cpp =
[
    [ "BuildRoadToolbarWindow", "d7/d35/structBuildRoadToolbarWindow.html", "d7/d35/structBuildRoadToolbarWindow" ],
    [ "BuildRoadDepotWindow", "de/d4a/structBuildRoadDepotWindow.html", "de/d4a/structBuildRoadDepotWindow" ],
    [ "BuildRoadStationWindow", "dc/d4a/structBuildRoadStationWindow.html", "dc/d4a/structBuildRoadStationWindow" ],
    [ "OnButtonClick", "df/dea/road__gui_8cpp.html#a91de73995dd3144aa9c9837202e4afc3", null ],
    [ "RoadFlags", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4", [
      [ "RF_NONE", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4adfaed4cc271948c659c2f1aadea250ef", null ],
      [ "RF_START_HALFROAD_Y", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4afd4af0fadb1166c9e6aa74555bee2b61", null ],
      [ "RF_END_HALFROAD_Y", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a560603c8d9d7406b5c74a7b6fa52c9ba", null ],
      [ "RF_DIR_Y", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a7f2430f6117646323803d916b81e33ba", null ],
      [ "RF_DIR_X", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a8148e364627b79f3e87010a5c4ec5aad", null ],
      [ "RF_START_HALFROAD_X", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a2fe36db344ea801bb5c58e418c901a20", null ],
      [ "RF_END_HALFROAD_X", "df/dea/road__gui_8cpp.html#a8b6adc09d2405c8f52228d8913ab32d4a4825b11225162ac4a227c200ba90b1bd", null ]
    ] ],
    [ "CcBuildRoadTunnel", "df/dea/road__gui_8cpp.html#aff9c6386a07e44155dee1dd4339d167b", null ],
    [ "CcPlaySound_SPLAT_OTHER", "df/dea/road__gui_8cpp.html#a75fc4e6cce4613b2c385ddf5ab3b1a95", null ],
    [ "CcRoadDepot", "df/dea/road__gui_8cpp.html#a719266f7962b4142db7c6b9668968e13", null ],
    [ "CcRoadStop", "df/dea/road__gui_8cpp.html#a06dd9c3fd1465bf207da623bfd892740", null ],
    [ "ConnectRoadToStructure", "df/dea/road__gui_8cpp.html#af20a3d9c0f4cd8f947e4da3a1048cb8e", null ],
    [ "GetRoadTypeDropDownList", "df/dea/road__gui_8cpp.html#ab6c8f8d3e96b9f77506a0240bf2418ed", null ],
    [ "GetScenRoadTypeDropDownList", "df/dea/road__gui_8cpp.html#ac74e19cf4dca8abe281749516e1c9a5a", null ],
    [ "InitializeRoadGui", "df/dea/road__gui_8cpp.html#aeb6ddffa8114c12dc4db43f9829ad0b1", null ],
    [ "InitializeRoadGUI", "df/dea/road__gui_8cpp.html#a09b2b5f8495657a81141fb479485521f", null ],
    [ "PlaceRoad_Bridge", "df/dea/road__gui_8cpp.html#a6adeef8b682097227bee2a9b6074843c", null ],
    [ "PlaceRoad_BusStation", "df/dea/road__gui_8cpp.html#a91c5755d81d600b47916247e287a1662", null ],
    [ "PlaceRoad_TruckStation", "df/dea/road__gui_8cpp.html#a425e1752188eeb4b1dccfe2b343ac766", null ],
    [ "PlaceRoadStop", "df/dea/road__gui_8cpp.html#a7d5ca3a311d57669138f9abce00e8a72", null ],
    [ "RoadToolbar_CtrlChanged", "df/dea/road__gui_8cpp.html#abde0f691351de29fec3b895f384ccfd6", null ],
    [ "RoadToolbarGlobalHotkeys", "df/dea/road__gui_8cpp.html#a6825122229da57dda0ece0f0bb21ac5c", null ],
    [ "RoadTramToolbarGlobalHotkeys", "df/dea/road__gui_8cpp.html#aea317cabab3556601296a1ef4b47a657", null ],
    [ "ShowBuildRoadScenToolbar", "df/dea/road__gui_8cpp.html#a59954be019406712b5620c03f041e9fd", null ],
    [ "ShowBuildRoadToolbar", "df/dea/road__gui_8cpp.html#a2a953f6481c78539acd18c78e2570dfa", null ],
    [ "ShowRoadDepotPicker", "df/dea/road__gui_8cpp.html#a545cc3523b93794d9142af498d524c43", null ],
    [ "ShowRVStationPicker", "df/dea/road__gui_8cpp.html#a6ef2e122432f64f35d89c8887a85ec25", null ],
    [ "ToggleRoadButton_Remove", "df/dea/road__gui_8cpp.html#aaefa0d76e71df66edba5a5db0fd3bf4d", null ],
    [ "TramToolbarGlobalHotkeys", "df/dea/road__gui_8cpp.html#a3c76d4a16b2c65cc2f979c31777ca0ec", null ],
    [ "_build_road_depot_desc", "df/dea/road__gui_8cpp.html#a80251a86817a6f759d37bec66b05c46b", null ],
    [ "_build_road_desc", "df/dea/road__gui_8cpp.html#a201cc3543a8d163d3b41d74078486deb", null ],
    [ "_build_road_scen_desc", "df/dea/road__gui_8cpp.html#a4cb686f5a1c2980c2be62d405e7f5dac", null ],
    [ "_build_tramway_desc", "df/dea/road__gui_8cpp.html#a06b1bc4ae125de155ccf781347fc3d51", null ],
    [ "_build_tramway_scen_desc", "df/dea/road__gui_8cpp.html#ab90e361fefb8517eba8ac3bdf31f1bf4", null ],
    [ "_cur_roadtype", "df/dea/road__gui_8cpp.html#a47c9c607737150786f26d25f419b7a87", null ],
    [ "_nested_build_road_depot_widgets", "df/dea/road__gui_8cpp.html#aa0f23e6a09c47e9102326a7912699edb", null ],
    [ "_nested_build_road_scen_widgets", "df/dea/road__gui_8cpp.html#ab813e468ce61df77234ae8775d7dba22", null ],
    [ "_nested_build_road_widgets", "df/dea/road__gui_8cpp.html#a1ef3d3de78bd5ca692d04e959c6b3da5", null ],
    [ "_nested_build_tramway_scen_widgets", "df/dea/road__gui_8cpp.html#a5f230eead7dc76e590cb7bdb5fddf1ae", null ],
    [ "_nested_build_tramway_widgets", "df/dea/road__gui_8cpp.html#aa59215c8725524bfc9087a3bd702207d", null ],
    [ "_nested_road_station_picker_widgets", "df/dea/road__gui_8cpp.html#a7e19be87654b6ba1d90fd54743de2240", null ],
    [ "_nested_tram_station_picker_widgets", "df/dea/road__gui_8cpp.html#a7a2a397228a9761da8c90697f588e764", null ],
    [ "_one_way_button_clicked", "df/dea/road__gui_8cpp.html#a6cc12fcacadf22b33d111a93607a80f4", null ],
    [ "_place_road_flag", "df/dea/road__gui_8cpp.html#ae039979b32acc50dc75b8c7690db6c21", null ],
    [ "_remove_button_clicked", "df/dea/road__gui_8cpp.html#ae2f45bd332449fcc37e8265e155de154", null ],
    [ "_road_depot_orientation", "df/dea/road__gui_8cpp.html#afea3a0159238725096070659d7887549", null ],
    [ "_road_station_picker_desc", "df/dea/road__gui_8cpp.html#aff6e966962634979fae4414a245b7dbe", null ],
    [ "_road_station_picker_orientation", "df/dea/road__gui_8cpp.html#af77a37be42e7289a8af6a05f3b37760c", null ],
    [ "_tram_station_picker_desc", "df/dea/road__gui_8cpp.html#ae55278fa96253c6666538ad5ea4f47b5", null ],
    [ "roadtoolbar_hotkeys", "df/dea/road__gui_8cpp.html#adaeec794b2cc8abe9b5084c5226ba767", null ],
    [ "tramtoolbar_hotkeys", "df/dea/road__gui_8cpp.html#a4ec45e782eeea0071c3a98b7ed2f75fe", null ]
];
